==> library-0.0.3-sources.jar: app/pitech/event/model/Extra.kt <==
package app.pitech.event.model

class Extra {
    lateinit var d1: String 
    lateinit var d2: String 
    lateinit var d3: String 
    lateinit var d4: String 
    lateinit var d5: String 
    lateinit var d6: String 
    lateinit var d7: String 
    lateinit var d8: String 
    lateinit var d9: String 
    lateinit var d10: String 
    lateinit var d11: String 
    lateinit var d12: String 
    lateinit var d13: String 
    lateinit var d14: String 
    lateinit var d15: String 
    lateinit var d16: String 
    lateinit var d17: String 
    lateinit var d18: String 
    lateinit var d19: String 
    lateinit var d20: String 
    lateinit var d21: String 
    lateinit var d22: String 
    lateinit var d23: String 
    lateinit var d24: String 
    lateinit var d25: String 
    lateinit var d26: String 
    lateinit var d27: String 
    lateinit var d28: String 
    lateinit var d29: String 
    lateinit var d30: String 
    lateinit var d31: String 
    lateinit var d32: String 
    lateinit var d33: String 
    lateinit var d34: String 
    lateinit var d35: String 
    lateinit var d36: String 
    lateinit var d37: String 
    lateinit var d38: String 
    lateinit var d39: String 
    lateinit var d40: String 
    lateinit var d41: String 
    lateinit var d42: String 
    lateinit var d43: String 
    lateinit var d44: String 
    lateinit var d45: String 
    lateinit var d46: String 
    lateinit var d47: String 
    lateinit var d48: String 
    lateinit var d49: String 
    lateinit var d50: String 
    lateinit var d51: String 
    lateinit var d52: String 
    lateinit var d53: String 
    lateinit var d54: String 
    lateinit var d55: String 
    lateinit var d56: String 
    lateinit var d57: String 
    lateinit var d58: String 
    lateinit var d59: String 
    lateinit var d60: String 
    lateinit var d61: String 
    lateinit var d62: String 
    lateinit var d63: String 
    lateinit var d64: String 
    lateinit var d65: String 
    lateinit var d66: String 
    lateinit var d67: String 
    lateinit var d68: String 
    lateinit var d69: String 
    lateinit var d70: String 
    lateinit var d71: String 
    lateinit var d72: String 
    lateinit var d73: String 
    lateinit var d74: String 
    lateinit var d75: String 
    lateinit var d76: String 
    lateinit var d77: String 
    lateinit var d78: String 
    lateinit var d79: String 
    lateinit var d80: String 
    lateinit var d81: String 
    lateinit var d82: String 
    lateinit var d83: String 
    lateinit var d84: String 
    lateinit var d85: String 
    lateinit var d86: String 
    lateinit var d87: String 
    lateinit var d88: String 
    lateinit var d89: String 
    lateinit var d90: String 
    lateinit var d91: String 
    lateinit var d92: String 
    lateinit var d93: String 
    lateinit var d94: String 
    lateinit var d95: String 
    lateinit var d96: String 
    lateinit var d97: String 
    lateinit var d98: String 
    lateinit var d99: String 
    lateinit var d100: String 

    fun set01(data: String): Extra {
        d1 = data
        return this
    }

    fun set02(data: String): Extra {
        d2 = data
        return this
    }

    fun set03(data: String): Extra {
        d3 = data
        return this
    }

    fun set04(data: String): Extra {
        d4 = data
        return this
    }

    fun set05(data: String): Extra {
        d5 = data
        return this
    }

    fun set06(data: String): Extra {
        d6 = data
        return this
    }

    fun set07(data: String): Extra {
        d7 = data
        return this
    }

    fun set08(data: String): Extra {
        d8 = data
        return this
    }

    fun set09(data: String): Extra {
        d9 = data
        return this
    }

    fun set10(data: String): Extra {
        d10 = data
        return this
    }

    fun set11(data: String): Extra {
        d11 = data
        return this
    }

    fun set12(data: String): Extra {
        d12 = data
        return this
    }

    fun set13(data: String): Extra {
        d13 = data
        return this
    }

    fun set14(data: String): Extra {
        d14 = data
        return this
    }

    fun set15(data: String): Extra {
        d15 = data
        return this
    }

    fun set16(data: String): Extra {
        d16 = data
        return this
    }

    fun set17(data: String): Extra {
        d17 = data
        return this
    }

    fun set18(data: String): Extra {
        d18 = data
        return this
    }

    fun set19(data: String): Extra {
        d19 = data
        return this
    }

    fun set20(data: String): Extra {
        d20 = data
        return this
    }

    fun set21(data: String): Extra {
        d21 = data
        return this
    }

    fun set22(data: String): Extra {
        d22 = data
        return this
    }

    fun set23(data: String): Extra {
        d23 = data
        return this
    }

    fun set24(data: String): Extra {
        d24 = data
        return this
    }

    fun set25(data: String): Extra {
        d25 = data
        return this
    }

    fun set26(data: String): Extra {
        d26 = data
        return this
    }

    fun set27(data: String): Extra {
        d27 = data
        return this
    }

    fun set28(data: String): Extra {
        d28 = data
        return this
    }

    fun set29(data: String): Extra {
        d29 = data
        return this
    }

    fun set30(data: String): Extra {
        d30 = data
        return this
    }

    fun set31(data: String): Extra {
        d31 = data
        return this
    }

    fun set32(data: String): Extra {
        d32 = data
        return this
    }

    fun set33(data: String): Extra {
        d33 = data
        return this
    }

    fun set34(data: String): Extra {
        d34 = data
        return this
    }

    fun set35(data: String): Extra {
        d35 = data
        return this
    }

    fun set36(data: String): Extra {
        d36 = data
        return this
    }

    fun set37(data: String): Extra {
        d37 = data
        return this
    }

    fun set38(data: String): Extra {
        d38 = data
        return this
    }

    fun set39(data: String): Extra {
        d39 = data
        return this
    }

    fun set40(data: String): Extra {
        d40 = data
        return this
    }

    fun set41(data: String): Extra {
        d41 = data
        return this
    }

    fun set42(data: String): Extra {
        d42 = data
        return this
    }

    fun set43(data: String): Extra {
        d43 = data
        return this
    }

    fun set44(data: String): Extra {
        d44 = data
        return this
    }

    fun set45(data: String): Extra {
        d45 = data
        return this
    }

    fun set46(data: String): Extra {
        d46 = data
        return this
    }

    fun set47(data: String): Extra {
        d47 = data
        return this
    }

    fun set48(data: String): Extra {
        d48 = data
        return this
    }

    fun set49(data: String): Extra {
        d49 = data
        return this
    }

    fun set50(data: String): Extra {
        d50 = data
        return this
    }

    fun set51(data: String): Extra {
        d51 = data
        return this
    }

    fun set52(data: String): Extra {
        d52 = data
        return this
    }

    fun set53(data: String): Extra {
        d53 = data
        return this
    }

    fun set54(data: String): Extra {
        d54 = data
        return this
    }

    fun set55(data: String): Extra {
        d55 = data
        return this
    }

    fun set56(data: String): Extra {
        d56 = data
        return this
    }

    fun set57(data: String): Extra {
        d57 = data
        return this
    }

    fun set58(data: String): Extra {
        d58 = data
        return this
    }

    fun set59(data: String): Extra {
        d59 = data
        return this
    }

    fun set60(data: String): Extra {
        d60 = data
        return this
    }

    fun set61(data: String): Extra {
        d61 = data
        return this
    }

    fun set62(data: String): Extra {
        d62 = data
        return this
    }

    fun set63(data: String): Extra {
        d63 = data
        return this
    }

    fun set64(data: String): Extra {
        d64 = data
        return this
    }

    fun set65(data: String): Extra {
        d65 = data
        return this
    }

    fun set66(data: String): Extra {
        d66 = data
        return this
    }

    fun set67(data: String): Extra {
        d67 = data
        return this
    }

    fun set68(data: String): Extra {
        d68 = data
        return this
    }

    fun set69(data: String): Extra {
        d69 = data
        return this
    }

    fun set70(data: String): Extra {
        d70 = data
        return this
    }

    fun set71(data: String): Extra {
        d71 = data
        return this
    }

    fun set72(data: String): Extra {
        d72 = data
        return this
    }

    fun set73(data: String): Extra {
        d73 = data
        return this
    }

    fun set74(data: String): Extra {
        d74 = data
        return this
    }

    fun set75(data: String): Extra {
        d75 = data
        return this
    }

    fun set76(data: String): Extra {
        d76 = data
        return this
    }

    fun set77(data: String): Extra {
        d77 = data
        return this
    }

    fun set78(data: String): Extra {
        d78 = data
        return this
    }

    fun set79(data: String): Extra {
        d79 = data
        return this
    }

    fun set80(data: String): Extra {
        d80 = data
        return this
    }


    fun set81(data: String): Extra {
        d81 = data
        return this
    }

    fun set82(data: String): Extra {
        d82 = data
        return this
    }

    fun set83(data: String): Extra {
        d83 = data
        return this
    }

    fun set84(data: String): Extra {
        d84 = data
        return this
    }

    fun set85(data: String): Extra {
        d85 = data
        return this
    }

    fun set86(data: String): Extra {
        d86 = data
        return this
    }

    fun set87(data: String): Extra {
        d87 = data
        return this
    }

    fun set88(data: String): Extra {
        d88 = data
        return this
    }

    fun set89(data: String): Extra {
        d89 = data
        return this
    }

    fun set90(data: String): Extra {
        d90 = data
        return this
    }

    fun set91(data: String): Extra {
        d91 = data
        return this
    }

    fun set92(data: String): Extra {
        d92 = data
        return this
    }

    fun set93(data: String): Extra {
        d93 = data
        return this
    }

    fun set94(data: String): Extra {
        d94 = data
        return this
    }

    fun set95(data: String): Extra {
        d95 = data
        return this
    }

    fun set96(data: String): Extra {
        d96 = data
        return this
    }

    fun set97(data: String): Extra {
        d97 = data
        return this
    }

    fun set98(data: String): Extra {
        d98 = data
        return this
    }

    fun set99(data: String): Extra {
        d99 = data
        return this
    }

    fun set100(data: String): Extra {
        d100 = data
        return this
    }

}

==> library-0.1.5-sources.jar: app/pitech/event/model/Extra.kt <==
package app.pitech.event.model

class Extra {
    var d1: String = ""
    var d2: String = ""
    var d3: String = ""
    var d4: String = ""
    var d5: String = ""
    var d6: String = ""
    var d7: String = ""
    var d8: String = ""
    var d9: String = ""
    var d10: String = ""
    var d11: String = ""
    var d12: String = ""
    var d13: String = ""
    var d14: String = ""
    var d15: String = ""
    var d16: String = ""
    var d17: String = ""
    var d18: String = ""
    var d19: String = ""
    var d20: String = ""
    var d21: String = ""
    var d22: String = ""
    var d23: String = ""
    var d24: String = ""
    var d25: String = ""
    var d26: String = ""
    var d27: String = ""
    var d28: String = ""
    var d29: String = ""
    var d30: String = ""
    var d31: String = ""
    var d32: String = ""
    var d33: String = ""
    var d34: String = ""
    var d35: String = ""
    var d36: String = ""
    var d37: String = ""
    var d38: String = ""
    var d39: String = ""
    var d40: String = ""
    var d41: String = ""
    var d42: String = ""
    var d43: String = ""
    var d44: String = ""
    var d45: String = ""
    var d46: String = ""
    var d47: String = ""
    var d48: String = ""
    var d49: String = ""
    var d50: String = ""
    var d51: String = ""
    var d52: String = ""
    var d53: String = ""
    var d54: String = ""
    var d55: String = ""
    var d56: String = ""
    var d57: String = ""
    var d58: String = ""
    var d59: String = ""
    var d60: String = ""
    var d61: String = ""
    var d62: String = ""
    var d63: String = ""
    var d64: String = ""
    var d65: String = ""
    var d66: String = ""
    var d67: String = ""
    var d68: String = ""
    var d69: String = ""
    var d70: String = ""
    var d71: String = ""
    var d72: String = ""
    var d73: String = ""
    var d74: String = ""
    var d75: String = ""
    var d76: String = ""
    var d77: String = ""
    var d78: String = ""
    var d79: String = ""
    var d80: String = ""
    var d81: String = ""
    var d82: String = ""
    var d83: String = ""
    var d84: String = ""
    var d85: String = ""
    var d86: String = ""
    var d87: String = ""
    var d88: String = ""
    var d89: String = ""
    var d90: String = ""
    var d91: String = ""
    var d92: String = ""
    var d93: String = ""
    var d94: String = ""
    var d95: String = ""
    var d96: String = ""
    var d97: String = ""
    var d98: String = ""
    var d99: String = ""
    var d100: String = ""

    fun set01(data: String): Extra {
        d1 = data
        return this
    }

    fun set02(data: String): Extra {
        d2 = data
        return this
    }

    fun set03(data: String): Extra {
        d3 = data
        return this
    }

    fun set04(data: String): Extra {
        d4 = data
        return this
    }

    fun set05(data: String): Extra {
        d5 = data
        return this
    }

    fun set06(data: String): Extra {
        d6 = data
        return this
    }

    fun set07(data: String): Extra {
        d7 = data
        return this
    }

    fun set08(data: String): Extra {
        d8 = data
        return this
    }

    fun set09(data: String): Extra {
        d9 = data
        return this
    }

    fun set10(data: String): Extra {
        d10 = data
        return this
    }

    fun set11(data: String): Extra {
        d11 = data
        return this
    }

    fun set12(data: String): Extra {
        d12 = data
        return this
    }

    fun set13(data: String): Extra {
        d13 = data
        return this
    }

    fun set14(data: String): Extra {
        d14 = data
        return this
    }

    fun set15(data: String): Extra {
        d15 = data
        return this
    }

    fun set16(data: String): Extra {
        d16 = data
        return this
    }

    fun set17(data: String): Extra {
        d17 = data
        return this
    }

    fun set18(data: String): Extra {
        d18 = data
        return this
    }

    fun set19(data: String): Extra {
        d19 = data
        return this
    }

    fun set20(data: String): Extra {
        d20 = data
        return this
    }

    fun set21(data: String): Extra {
        d21 = data
        return this
    }

    fun set22(data: String): Extra {
        d22 = data
        return this
    }

    fun set23(data: String): Extra {
        d23 = data
        return this
    }

    fun set24(data: String): Extra {
        d24 = data
        return this
    }

    fun set25(data: String): Extra {
        d25 = data
        return this
    }

    fun set26(data: String): Extra {
        d26 = data
        return this
    }

    fun set27(data: String): Extra {
        d27 = data
        return this
    }

    fun set28(data: String): Extra {
        d28 = data
        return this
    }

    fun set29(data: String): Extra {
        d29 = data
        return this
    }

    fun set30(data: String): Extra {
        d30 = data
        return this
    }

    fun set31(data: String): Extra {
        d31 = data
        return this
    }

    fun set32(data: String): Extra {
        d32 = data
        return this
    }

    fun set33(data: String): Extra {
        d33 = data
        return this
    }

    fun set34(data: String): Extra {
        d34 = data
        return this
    }

    fun set35(data: String): Extra {
        d35 = data
        return this
    }

    fun set36(data: String): Extra {
        d36 = data
        return this
    }

    fun set37(data: String): Extra {
        d37 = data
        return this
    }

    fun set38(data: String): Extra {
        d38 = data
        return this
    }

    fun set39(data: String): Extra {
        d39 = data
        return this
    }

    fun set40(data: String): Extra {
        d40 = data
        return this
    }

    fun set41(data: String): Extra {
        d41 = data
        return this
    }

    fun set42(data: String): Extra {
        d42 = data
        return this
    }

    fun set43(data: String): Extra {
        d43 = data
        return this
    }

    fun set44(data: String): Extra {
        d44 = data
        return this
    }

    fun set45(data: String): Extra {
        d45 = data
        return this
    }

    fun set46(data: String): Extra {
        d46 = data
        return this
    }

    fun set47(data: String): Extra {
        d47 = data
        return this
    }

    fun set48(data: String): Extra {
        d48 = data
        return this
    }

    fun set49(data: String): Extra {
        d49 = data
        return this
    }

    fun set50(data: String): Extra {
        d50 = data
        return this
    }

    fun set51(data: String): Extra {
        d51 = data
        return this
    }

    fun set52(data: String): Extra {
        d52 = data
        return this
    }

    fun set53(data: String): Extra {
        d53 = data
        return this
    }

    fun set54(data: String): Extra {
        d54 = data
        return this
    }

    fun set55(data: String): Extra {
        d55 = data
        return this
    }

    fun set56(data: String): Extra {
        d56 = data
        return this
    }

    fun set57(data: String): Extra {
        d57 = data
        return this
    }

    fun set58(data: String): Extra {
        d58 = data
        return this
    }

    fun set59(data: String): Extra {
        d59 = data
        return this
    }

    fun set60(data: String): Extra {
        d60 = data
        return this
    }

    fun set61(data: String): Extra {
        d61 = data
        return this
    }

    fun set62(data: String): Extra {
        d62 = data
        return this
    }

    fun set63(data: String): Extra {
        d63 = data
        return this
    }

    fun set64(data: String): Extra {
        d64 = data
        return this
    }

    fun set65(data: String): Extra {
        d65 = data
        return this
    }

    fun set66(data: String): Extra {
        d66 = data
        return this
    }

    fun set67(data: String): Extra {
        d67 = data
        return this
    }

    fun set68(data: String): Extra {
        d68 = data
        return this
    }

    fun set69(data: String): Extra {
        d69 = data
        return this
    }

    fun set70(data: String): Extra {
        d70 = data
        return this
    }

    fun set71(data: String): Extra {
        d71 = data
        return this
    }

    fun set72(data: String): Extra {
        d72 = data
        return this
    }

    fun set73(data: String): Extra {
        d73 = data
        return this
    }

    fun set74(data: String): Extra {
        d74 = data
        return this
    }

    fun set75(data: String): Extra {
        d75 = data
        return this
    }

    fun set76(data: String): Extra {
        d76 = data
        return this
    }

    fun set77(data: String): Extra {
        d77 = data
        return this
    }

    fun set78(data: String): Extra {
        d78 = data
        return this
    }

    fun set79(data: String): Extra {
        d79 = data
        return this
    }

    fun set80(data: String): Extra {
        d80 = data
        return this
    }


    fun set81(data: String): Extra {
        d81 = data
        return this
    }

    fun set82(data: String): Extra {
        d82 = data
        return this
    }

    fun set83(data: String): Extra {
        d83 = data
        return this
    }

    fun set84(data: String): Extra {
        d84 = data
        return this
    }

    fun set85(data: String): Extra {
        d85 = data
        return this
    }

    fun set86(data: String): Extra {
        d86 = data
        return this
    }

    fun set87(data: String): Extra {
        d87 = data
        return this
    }

    fun set88(data: String): Extra {
        d88 = data
        return this
    }

    fun set89(data: String): Extra {
        d89 = data
        return this
    }

    fun set90(data: String): Extra {
        d90 = data
        return this
    }

    fun set91(data: String): Extra {
        d91 = data
        return this
    }

    fun set92(data: String): Extra {
        d92 = data
        return this
    }

    fun set93(data: String): Extra {
        d93 = data
        return this
    }

    fun set94(data: String): Extra {
        d94 = data
        return this
    }

    fun set95(data: String): Extra {
        d95 = data
        return this
    }

    fun set96(data: String): Extra {
        d96 = data
        return this
    }

    fun set97(data: String): Extra {
        d97 = data
        return this
    }

    fun set98(data: String): Extra {
        d98 = data
        return this
    }

    fun set99(data: String): Extra {
        d99 = data
        return this
    }

    fun set100(data: String): Extra {
        d100 = data
        return this
    }

}
